Skip to contents

Convert an edge list to a sparse adjacency matrix

Usage

EdgetoAdj(E, N)

Arguments

E

Two-column edge list with source and target vertex indices.

N

Total number of vertices.

Value

A sparse adjacency matrix of class dgCMatrix.