Skip to contents

Read a cell-to-ligand compatibility matrix

Usage

createCellLigList(filename)

Arguments

filename

Path to a CSV file with cell types in rows and ligands in columns.

Value

A list containing the matrix plus ligand and cell-type labels.