Skip to contents

Read a cell-to-receptor compatibility matrix

Usage

createCellRecList(filename)

Arguments

filename

Path to a CSV file with cell types in rows and receptors in columns.

Value

A list containing the matrix plus receptor and cell-type labels.