R/Utilities.R
EdgetoAdj.Rd
Convert an edge list to a sparse adjacency matrix
EdgetoAdj(E, N)
Two-column edge list with source and target vertex indices.
Total number of vertices.
A sparse adjacency matrix of class dgCMatrix.
dgCMatrix