Convert an edge list to a sparse adjacency matrix without self-loops
Source:R/Utilities.R
EdgetoAdj_No_loop.RdConvert an edge list to a sparse adjacency matrix without self-loops
R/Utilities.R
EdgetoAdj_No_loop.RdConvert an edge list to a sparse adjacency matrix without self-loops