R/RaCInG_input_generation.R
createCellLigList.Rd
Read a cell-to-ligand compatibility matrix
createCellLigList(filename)
Path to a CSV file with cell types in rows and ligands in columns.
A list containing the matrix plus ligand and cell-type labels.